# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.Content.V21.Model.InputField do
  @moduledoc """
  Input field that needs to be available to the merchant. If the field is marked as required, then a value needs to be provided for a successful processing of the request.

  ## Attributes

  *   `checkboxInput` (*type:* `GoogleApi.Content.V21.Model.InputFieldCheckboxInput.t`, *default:* `nil`) - Input field to provide a boolean value. Corresponds to the [html input type=checkbox](https://www.w3.org/TR/2012/WD-html-markup-20121025/input.checkbox.html#input.checkbox).
  *   `choiceInput` (*type:* `GoogleApi.Content.V21.Model.InputFieldChoiceInput.t`, *default:* `nil`) - Input field to select one of the offered choices. Corresponds to the [html input type=radio](https://www.w3.org/TR/2012/WD-html-markup-20121025/input.radio.html#input.radio).
  *   `id` (*type:* `String.t`, *default:* `nil`) - Not for display but need to be sent back for the given input field.
  *   `label` (*type:* `GoogleApi.Content.V21.Model.TextWithTooltip.t`, *default:* `nil`) - Input field label. There may be more information to be shown in a tooltip.
  *   `required` (*type:* `boolean()`, *default:* `nil`) - Whether the field is required. The action button needs to stay disabled till values for all required fields are provided.
  *   `textInput` (*type:* `GoogleApi.Content.V21.Model.InputFieldTextInput.t`, *default:* `nil`) - Input field to provide text information. Corresponds to the [html input type=text](https://www.w3.org/TR/2012/WD-html-markup-20121025/input.text.html#input.text) or [html textarea](https://www.w3.org/TR/2012/WD-html-markup-20121025/textarea.html#textarea).
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :checkboxInput => GoogleApi.Content.V21.Model.InputFieldCheckboxInput.t() | nil,
          :choiceInput => GoogleApi.Content.V21.Model.InputFieldChoiceInput.t() | nil,
          :id => String.t() | nil,
          :label => GoogleApi.Content.V21.Model.TextWithTooltip.t() | nil,
          :required => boolean() | nil,
          :textInput => GoogleApi.Content.V21.Model.InputFieldTextInput.t() | nil
        }

  field(:checkboxInput, as: GoogleApi.Content.V21.Model.InputFieldCheckboxInput)
  field(:choiceInput, as: GoogleApi.Content.V21.Model.InputFieldChoiceInput)
  field(:id)
  field(:label, as: GoogleApi.Content.V21.Model.TextWithTooltip)
  field(:required)
  field(:textInput, as: GoogleApi.Content.V21.Model.InputFieldTextInput)
end

defimpl Poison.Decoder, for: GoogleApi.Content.V21.Model.InputField do
  def decode(value, options) do
    GoogleApi.Content.V21.Model.InputField.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.Content.V21.Model.InputField do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
